@@ -3,28 +3,17 @@
 
 ### requires "png" and "gplots" packages
 
-plot.altf3 <- function(x, ...)
+plot.altf3 <- function(x, non.interactive=NULL, ...)
   {
-    if (requireNamespace('graphics')) 
-      {
-      } 
-    else 
-      {
-        stop("package >>graphics<< is required")
-      }
-   
  
 plot1g <- function(x)
   {
-    
-    if (requireNamespace('png')) 
+  
+    if (is.null(non.interactive)) 
       {
-      } 
-    else 
-      {
-        stop("package >>png<< is required")
+        non.interactive <- FALSE
       }
-
+    
     names <- colnames(x$coeff.[[1]])
     
     inc <- vector()
@@ -75,14 +64,6 @@ plot1g <- function(x)
 plot2g <- function(x)
   {
     
-    if (requireNamespace('png')) 
-      {
-      } 
-    else 
-      {
-        stop("package >>png<< is required")
-      }
-
     names <- colnames(x$p.val.[[1]])
     
     inc <- vector()
@@ -132,24 +113,8 @@ plot2g <- function(x)
 
 plot3g <- function(x)
   {
-    if (requireNamespace('gplots')) 
-      { 
-        col <- rich.colors(ncol(x$weights[[1]]), palette="temperature", rgb=FALSE, plot=FALSE) 
-      } 
-    else 
-      {
-        warning("package >>gplots<< is required ::: a plot might be blurred")
-        col <- seq(1:ncol(x$weights[[1]]))
-      }
+    col <- rich.colors(ncol(x$weights[[1]]), palette="temperature", rgb=FALSE, plot=FALSE) 
     
-    if (requireNamespace('png')) 
-      {
-      } 
-    else 
-      {
-        stop("package >>png<< is required")
-      }
-
     inc <- vector()
     inc[1] <- 1
     for (i in 1:7)
@@ -174,13 +139,6 @@ plot3g <- function(x)
 
 plot4g <- function(x)
   {
-    if (requireNamespace('png')) 
-      {
-      } 
-    else 
-      {
-        stop("package >>png<< is required")
-      }
 
     inc <- vector()
     inc[1] <- 1
@@ -199,14 +157,22 @@ plot4g <- function(x)
 
   }
 
- 
-        choices <- c("expected coefficients - separate plots (files in working directory)",
-                     "p-values for t-tests - separate plots (files in working directory)",
-                     "models' weights",
-                     "expected window size")
-        pick <- menu(choices = paste(" ", choices), title = "\nMake a plot selection (or 0 to exit):")
-        switch(pick, plot1g(x), plot2g(x), plot3g(x), plot4g(x))
-
+        if (non.interactive == FALSE) 
+          {
+            choices <- c("expected coefficients - separate plots (files in working directory)",
+                         "p-values for t-tests - separate plots (files in working directory)",
+                         "models' weights",
+                         "expected window size")
+            pick <- menu(choices = paste(" ", choices), title = "\nMake a plot selection (or 0 to exit):")
+            switch(pick, plot1g(x), plot2g(x), plot3g(x), plot4g(x))
+          }
+        else
+          {
+            plot1g(x)
+            plot2g(x)
+            plot3g(x)
+            plot4g(x)
+          }
  
   }
   
\ No newline at end of file
